(accept-invite invite accepted-by-user-id now)Transitions an invite to :accepted.
Transitions an invite to :accepted.
(expired? invite now)Returns true when the invite is no longer valid due to expiry.
Returns true when the invite is no longer valid due to expiry.
(normalize-email email)Normalize invite email for consistent matching.
Normalize invite email for consistent matching.
(prepare-invite* {:keys [invite-id tenant-id email role token-hash expires-at
metadata]}
now)Creates a new tenant invite in :pending status using explicit runtime inputs.
Creates a new tenant invite in :pending status using explicit runtime inputs.
(revoke-invite invite now)Transitions an invite to :revoked.
Transitions an invite to :revoked.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |