boundary.tenant.shell.persistence


create-tenant-repositoryclj

(create-tenant-repository ctx logger error-reporter)
source

initialize-tenant-schema!clj

(initialize-tenant-schema! ctx)

Initialize database schema for tenant entities using Malli schema definitions.

Creates the tenants and tenant_memberships tables from the Malli schemas.

Args: ctx: Database context

Returns: nil

Initialize database schema for tenant entities using Malli schema definitions.

Creates the tenants and tenant_memberships tables from the Malli schemas.

Args:
  ctx: Database context

Returns:
  nil
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries