(wrap-tenant-membership membership-service handler)Ring middleware that enriches the request with :tenant-membership.
Looks up the active membership for the current user+tenant pair (from :user and :tenant keys already set on the request by upstream middleware). Sets :tenant-membership to nil when no active membership is found or when either :user or :tenant is absent.
Args: membership-service - ITenantMembershipService implementation handler - next Ring handler
Returns: Ring handler.
Ring middleware that enriches the request with :tenant-membership. Looks up the active membership for the current user+tenant pair (from :user and :tenant keys already set on the request by upstream middleware). Sets :tenant-membership to nil when no active membership is found or when either :user or :tenant is absent. Args: membership-service - ITenantMembershipService implementation handler - next Ring handler Returns: Ring handler.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |