(initialize-tenant-schema! ctx)Initialize database schema for tenant entities using Malli schema definitions.
Creates the tenants and tenant_memberships tables from the Malli schemas.
Args: ctx: Database context
Returns: nil
Initialize database schema for tenant entities using Malli schema definitions. Creates the tenants and tenant_memberships tables from the Malli schemas. Args: ctx: Database context Returns: nil
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |